@@ -2,6 +2,4 @@
 # @Time    : 2020/10/22
 # @Author  : xiangyuejia@qq.com
 
-import aitool.basic_function as base
-
-import aitool.data_structure.graph as graph
\ No newline at end of file
+from aitool.basic_function.time_function import exe_time as exe_time
